@@ -1,10 +1,11 @@
+from build.lib.t2wml.parsing.classes import ReturnClass
 from collections import defaultdict
 import t2wml.utils.t2wml_exceptions as T2WMLExceptions
 from t2wml.parsing.t2wml_parsing import iter_on_n_for_code, T2WMLCode
 from t2wml.spreadsheets.conversions import to_excel
 from t2wml.wikification.utility_functions import get_property_type
 from t2wml.utils.utilities import VALID_PROPERTY_TYPES, parse_datetime, translate_precision_to_integer
-
+from t2wml.settings import t2wml_settings
 
 class Node:
     def __init__(self, property=None, value=None, **kwargs):
@@ -60,7 +61,7 @@ class Node:
 
     def validate_datetime(self):
         try:
-            datetime_string, parsed_precision = parse_datetime(
+            datetime_string, parsed_precision, used_format = parse_datetime(
                 self.value,
                 additional_formats=self.__dict__.get("format", []),
                 precisions=self.__dict__.get("precision", [])
@@ -68,6 +69,8 @@ class Node:
             self.value = datetime_string
             if parsed_precision:
                 self.precision = parsed_precision
+            if used_format:
+                self.format=used_format
         except:
             self._errors["value"] += "Invalid datetime: "+str(self.value)
 
@@ -154,13 +157,20 @@ class NodeForEval(Node):
                 try:
                     entry_parsed = iter_on_n_for_code(
                         self.__dict__[key], self.context)
-                    value = entry_parsed.value
+                    try:
+                        value = entry_parsed.value
+                    except AttributeError:
+                        if not isinstance(entry_parsed, ReturnClass): #sometimes parses to a string or number, not a returnclass
+                            value=str(entry_parsed)
+                        else:
+                            value=None
                     if value is None:
                         self._errors[key] += "Failed to resolve"
                         self.__dict__.pop(key)
                         # self.__dict__[key]=self.__dict__[key].unmodified_str
                     elif value=="":
-                        self._errors[key] += "Empty cell"
+                        if t2wml_settings.warn_for_empty_cells:
+                            self._errors[key] += "Empty cell"
                         self.__dict__.pop(key)
                     else:
                         self.__dict__[key] = value
